CachedPlaceSearchAdapter class

Constructors

CachedPlaceSearchAdapter()

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
typeId → int
Called for type registration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(BinaryReader reader) → CachedPlaceSearch
Is called when a value has to be decoded.
toString() → String
A string representation of this object.
inherited
write(BinaryWriter writer, CachedPlaceSearch obj) → void
Is called when a value has to be encoded.

Operators

operator ==(Object other) → bool
The equality operator.
override