isInitialised property
bool
get
isInitialised
Whether the service has been initialised and is ready to use.
Implementation
bool get isInitialised => _cacheBox != null && _cacheBox!.isOpen;
Whether the service has been initialised and is ready to use.
bool get isInitialised => _cacheBox != null && _cacheBox!.isOpen;